@@ -16,8 +16,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #include <qlabel.h>
 #include <qslider.h>
@@ -51,7 +51,7 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
     if (attr.value("type") == "spinbutton" ) {
 	QHBoxLayout *hb = new QHBoxLayout(this);
 	if (!mLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(mLabel), this);
+            QLabel *l = new QLabel(i18n(mLabel.utf8()), this);
 	    hb->add(l);
 	}
 	mSpinBox = new QSpinBox(mMinimum, mMaximum, 1, this);
@@ -63,19 +63,19 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
 	QString highLabel = attr.value("_high-label");
 	QVBoxLayout *vb = new QVBoxLayout(this);
 	if (!mLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(mLabel), this);
+            QLabel *l = new QLabel(i18n(mLabel.utf8()), this);
 	    vb->add(l);
 	}
 	QHBoxLayout *hb = new QHBoxLayout(vb);
 	if (!lowLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(lowLabel), this);
+            QLabel *l = new QLabel(i18n(lowLabel.utf8()), this);
 	    hb->addWidget(l);
 	}
 	mSlider = new QSlider(mMinimum, mMaximum, 10, mValue, Qt::Horizontal, this);
 	connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
 	hb->add(mSlider);
 	if (!highLabel.isEmpty()){
-	    QLabel *l = new QLabel(i18n(highLabel), this);
+            QLabel *l = new QLabel(i18n(highLabel.utf8()), this);
 	    hb->addWidget(l);
 	}
     }
@@ -120,12 +120,12 @@ KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
     QString highLabel = attr.value("_high-label");
     QVBoxLayout *vb = new QVBoxLayout(this);
     if (!mLabel.isEmpty()) {
-	QLabel *l = new QLabel(i18n(mLabel), this);
+        QLabel *l = new QLabel(i18n(mLabel.utf8()), this);
 	vb->add(l);
     }
     QHBoxLayout *hb = new QHBoxLayout(vb);
     if (!lowLabel.isEmpty()) {
-	QLabel *l = new QLabel(i18n(lowLabel), this);
+        QLabel *l = new QLabel(i18n(lowLabel.utf8()), this);
 	hb->addWidget(l);
     }
     int value = int((mValue - mMinimum) * 100 / (mMaximum - mMinimum));
@@ -133,7 +133,7 @@ KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
     connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
     hb->add(mSlider);
     if (!highLabel.isEmpty()){
-	QLabel *l = new QLabel(i18n(highLabel), this);
+        QLabel *l = new QLabel(i18n(highLabel.utf8()), this);
 	hb->addWidget(l);
     }
 }
@@ -147,7 +147,8 @@ void KXSDoubleRangeControl::slotValueChanged(int value)
 void KXSDoubleRangeControl::read(KConfig &config)
 {
     KXSDoubleRangeItem::read(config);
-    mSlider->setValue(mValue);
+    mSlider->setValue((int)((mValue - mMinimum) * 100.0 /
+                            (mMaximum - mMinimum) + 0.5));
 }
 
 //===========================================================================
@@ -164,7 +165,7 @@ KXSCheckBoxControl::KXSCheckBoxControl(QWidget *parent, const QString &name,
                                       const QXmlAttributes &attr)
   : QCheckBox(parent), KXSBoolItem(name, attr)
 {
-  setText(i18n(mLabel));
+  setText(i18n(mLabel.utf8()));
   setChecked(mValue);
   connect(this, SIGNAL(toggled(bool)), SLOT(slotToggled(bool)));
 }
@@ -190,8 +191,8 @@ KXSDropListControl::KXSDropListControl(QWidget *parent, const QString &name,
   QLabel *label = new QLabel(mLabel, this);
   l->add(label);
   mCombo = new QComboBox(this);
-  for(int i=0; i < mOptions.count(); i++)
-      mCombo->insertItem( i18n(mOptions[i]) );
+  for(uint i=0; i < mOptions.count(); i++)
+      mCombo->insertItem( i18n(mOptions[i].utf8()) );
   mCombo->setCurrentItem(mValue);
   connect(mCombo, SIGNAL(activated(int)), SLOT(slotActivated(int)));
   l->add(mCombo);
@@ -202,7 +203,7 @@ KXSDropListControl::KXSDropListControl(QWidget *parent, const QString &name,
   : QWidget(parent), KXSSelectItem(name, attr)
 {
   QVBoxLayout *l = new QVBoxLayout(this);
-  QLabel *label = new QLabel(i18n(mLabel), this);
+  QLabel *label = new QLabel(i18n(mLabel.utf8()), this);
   l->add(label);
   mCombo = new QComboBox(this);
   connect(mCombo, SIGNAL(activated(int)), SLOT(slotActivated(int)));
@@ -212,7 +213,7 @@ KXSDropListControl::KXSDropListControl(QWidget *parent, const QString &name,
 void KXSDropListControl::addOption(const QXmlAttributes &attr)
 {
     KXSSelectItem::addOption( attr );
-    mCombo->insertItem( i18n(mOptions[mOptions.count()-1]) );
+    mCombo->insertItem( i18n(mOptions[mOptions.count()-1].utf8()) );
     if ( (unsigned)mValue == mOptions.count()-1 )
 	mCombo->setCurrentItem(mOptions.count()-1);
 }
@@ -247,7 +248,7 @@ KXSLineEditControl::KXSLineEditControl(QWidget *parent, const QString &name,
   : QWidget(parent), KXSStringItem(name, attr)
 {
   QVBoxLayout *l = new QVBoxLayout(this);
-  QLabel *label = new QLabel(i18n(mLabel), this);
+  QLabel *label = new QLabel(i18n(mLabel.utf8()), this);
   l->add(label);
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
@@ -284,7 +285,7 @@ KXSFileControl::KXSFileControl(QWidget *parent, const QString &name,
   : QWidget(parent), KXSStringItem(name, attr)
 {
   QVBoxLayout *l = new QVBoxLayout(this);
-  QLabel *label = new QLabel(i18n(mLabel), this);
+  QLabel *label = new QLabel(i18n(mLabel.utf8()), this);
   l->add(label);
   QHBoxLayout *hb = new QHBoxLayout(l);
   mEdit = new QLineEdit(this);
